.. _ReferencePage:

=====
Reference
=====

.. sectnum:: :start: 2


See :ref:`UsagePage` for how to use these functions for common map manipulation tasks.

enmap - General map manipulation
-----

.. automodule:: pixell.enmap
   :members:    

fft - Fourier transforms
-----

.. automodule:: pixell.fft
   :members:    

curvedsky - Curved-sky harmonic transforms
-----

.. automodule:: pixell.curvedsky
   :members:          

utils - General utilities
-----

.. automodule:: pixell.utils
   :members:    
   
reproject - Map reprojection
-----
      
.. automodule:: pixell.reproject
   :members:    

resample - Map resampling
-----
      
.. automodule:: pixell.resample
   :members:
      
lensing - Lensing
-----
      
.. automodule:: pixell.lensing
   :members:

interpol - Interpolation
-----
      
.. automodule:: pixell.interpol
   :members:
      
coordinates - Coordinate Transformation
-----
      
.. automodule:: pixell.coordinates
   :members:
      

wcsutils - World Coordinate Sytem utilities
-----

.. automodule:: pixell.wcsutils
   :members:          

slice - Array slicing utilities
-----

.. automodule:: pixell.slice
   :members:          

powspec - CMB power spectra utilities
-----

.. automodule:: pixell.powspec
   :members:          
      
